summaryrefslogtreecommitdiffstats
path: root/amarok/src/directorylist.h
diff options
context:
space:
mode:
Diffstat (limited to 'amarok/src/directorylist.h')
-rw-r--r--amarok/src/directorylist.h27
1 files changed, 14 insertions, 13 deletions
diff --git a/amarok/src/directorylist.h b/amarok/src/directorylist.h
index ef8a89f1..543f2f21 100644
--- a/amarok/src/directorylist.h
+++ b/amarok/src/directorylist.h
@@ -29,20 +29,20 @@
namespace Collection { class Item; }
-class QFixedListView : public QListView
-// Reimplement sizeHint to have directorylist not being too big for "low" (1024x768 is not exactly low) resolutions
+class TQFixedListView : public TQListView
+// Reimplement tqsizeHint to have directorylist not being too big for "low" (1024x768 is not exactly low) resolutions
{
public:
- QFixedListView ( TQWidget * parent = 0, const char * name = 0, WFlags f = 0 )
- :TQListView(parent, name, f) {};
- TQSize sizeHint() const
+ TQFixedListView ( TQWidget * tqparent = 0, const char * name = 0, WFlags f = 0 )
+ :TQListView(tqparent, name, f) {};
+ TQSize tqsizeHint() const
{
return TQSize(400, 100);
}
};
-class CollectionSetup : public QVBox
+class CollectionSetup : public TQVBox
{
friend class Collection::Item;
@@ -59,7 +59,7 @@ public:
private:
static CollectionSetup* s_instance;
- QFixedListView *m_view;
+ TQFixedListView *m_view;
TQStringList m_dirs;
TQCheckBox *m_recursive;
TQCheckBox *m_monitor;
@@ -68,16 +68,17 @@ private:
namespace Collection { //just to keep it out of the global namespace
-class Item : public TQObject, public QCheckListItem
+class Item : public TQObject, public TQCheckListItem
{
Q_OBJECT
+ TQ_OBJECT
public:
- Item( TQListView *parent );
- Item( TQListViewItem *parent, const KURL &url , bool full_disable=false );
+ Item( TQListView *tqparent );
+ Item( TQListViewItem *tqparent, const KURL &url , bool full_disable=false );
- TQCheckListItem *parent() const { return static_cast<TQCheckListItem*>( TQListViewItem::parent() ); }
+ TQCheckListItem *tqparent() const { return static_cast<TQCheckListItem*>( TQListViewItem::tqparent() ); }
bool isFullyDisabled() const { return m_fullyDisabled; }
- bool isDisabled() const { return isFullyDisabled() || ( CollectionSetup::instance()->recursive() && parent() && parent()->isOn() ); }
+ bool isDisabled() const { return isFullyDisabled() || ( CollectionSetup::instance()->recursive() && tqparent() && tqparent()->isOn() ); }
TQString fullPath() const;
void setOpen( bool b ); // reimpl.
@@ -87,7 +88,7 @@ public:
public slots:
void newItems( const KFileItemList& );
- void completed() { if( childCount() == 0 ) { setExpandable( false ); repaint(); } }
+ void completed() { if( childCount() == 0 ) { setExpandable( false ); tqrepaint(); } }
private:
KDirLister m_lister;